@@ -36,6 +36,12 @@ describe('gives up if it cannot find the file', () => {
       'a/b/.foorc.yml',
       'a/b/.foorc.js',
       'a/b/.foorc.cjs',
+      'a/b/.config/foorc',
+      'a/b/.config/foorc.json',
+      'a/b/.config/foorc.yaml',
+      'a/b/.config/foorc.yml',
+      'a/b/.config/foorc.js',
+      'a/b/.config/foorc.cjs',
       'a/b/foo.config.js',
       'a/b/foo.config.cjs',
       'a/package.json',
@@ -45,6 +51,12 @@ describe('gives up if it cannot find the file', () => {
       'a/.foorc.yml',
       'a/.foorc.js',
       'a/.foorc.cjs',
+      'a/.config/foorc',
+      'a/.config/foorc.json',
+      'a/.config/foorc.yaml',
+      'a/.config/foorc.yml',
+      'a/.config/foorc.js',
+      'a/.config/foorc.cjs',
       'a/foo.config.js',
       'a/foo.config.cjs',
       'package.json',
@@ -54,6 +66,12 @@ describe('gives up if it cannot find the file', () => {
       '.foorc.yml',
       '.foorc.js',
       '.foorc.cjs',
+      '.config/foorc',
+      '.config/foorc.json',
+      '.config/foorc.yaml',
+      '.config/foorc.yml',
+      '.config/foorc.js',
+      '.config/foorc.cjs',
       'foo.config.js',
       'foo.config.cjs',
     ]);
@@ -92,6 +110,12 @@ describe('stops at stopDir and gives up', () => {
       'a/b/.foorc.yml',
       'a/b/.foorc.js',
       'a/b/.foorc.cjs',
+      'a/b/.config/foorc',
+      'a/b/.config/foorc.json',
+      'a/b/.config/foorc.yaml',
+      'a/b/.config/foorc.yml',
+      'a/b/.config/foorc.js',
+      'a/b/.config/foorc.cjs',
       'a/b/foo.config.js',
       'a/b/foo.config.cjs',
       'a/package.json',
@@ -101,6 +125,12 @@ describe('stops at stopDir and gives up', () => {
       'a/.foorc.yml',
       'a/.foorc.js',
       'a/.foorc.cjs',
+      'a/.config/foorc',
+      'a/.config/foorc.json',
+      'a/.config/foorc.yaml',
+      'a/.config/foorc.yml',
+      'a/.config/foorc.js',
+      'a/.config/foorc.cjs',
       'a/foo.config.js',
       'a/foo.config.cjs',
     ]);
